Result

Type Alias Result 

pub type Result<T = ()> = Result<T, TetraError>;
A specialized Result type for Tetra.

All Tetra functions with a recoverable failure condition will return this type. In your game code, you can either use it directly, or wrap it in your own error type.

Aliased Type

pub enum Result<T = ()> {
    Ok(T),
    Err(TetraError),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(TetraError)

Contains the error value