pub type Result<T = ()> = Result<T, TetraError>;Expand description
A specialized Result type for Tetra.
All Tetra functions with a recoverable failure condition will return this type. In your game code, you can either use it directly, or wrap it in your own error type.
Aliased Type
pub enum Result<T = ()> {
Ok(T),
Err(TetraError),
}